@@ -48,7 +48,7 @@ class VideoPredict(object):
 
     def capture_and_predict(self, url, camera):
         fps = camera.get(cv2.CAP_PROP_FPS)
-        if fps <= 0:
+        if fps <= 0 or fps > 30:
             fps = 30
 
         self.playlist[url] = {
